@@ -1,14 +1,13 @@
 """Generated protocol buffer code."""
+from google.protobuf.internal import builder as _builder
 from google.protobuf import descriptor as _descriptor
 from google.protobuf import descriptor_pool as _descriptor_pool
-from google.protobuf import message as _message
-from google.protobuf import reflection as _reflection
 from google.protobuf import symbol_database as _symbol_database
 _sym_db = _symbol_database.Default()
 from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
 DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17cosmos/msg/v1/msg.proto\x12\rcosmos.msg.v1\x1a google/protobuf/descriptor.proto:2\n\x06signer\x12\x1f.google.protobuf.MessageOptions\x18\xf0\x8c\xa6\x05 \x03(\tB/Z-github.com/cosmos/cosmos-sdk/types/msgserviceb\x06proto3')
-SIGNER_FIELD_NUMBER = 11110000
-signer = DESCRIPTOR.extensions_by_name['signer']
+_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
+_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.msg.v1.msg_pb2', globals())
 if _descriptor._USE_C_DESCRIPTORS == False:
     google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(signer)
     DESCRIPTOR._options = None
